Keeping live API objects... well, alive ❤️

Installing
==========

.. code-block:: bash

  pip3 install vessel

Links
-----

- `Documentation <https://vessel.readthedocs.io>`_

Warnings
--------

- Version ``3.0.0`` does not contain some core components. Check out `ldbcache <https://github.com/Exahilosys/ldbcache>`_ for database caching.
